# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-13


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.HostPrototype.hostPrototype_create import HostPrototypeCreate
from WorkApi.API.HostPrototype.hostPrototype_delete import HostPrototypeDelete

from WorkData.Zabbix.hosts import DataHosts

import allure

# allure.label("")


@allure.feature("测试模块：hostprototype.delete")
class TestHostPrototypeDelete(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机原型"
    base_ip = "10.0.0.28"
    base_hostid = 10266
    base_dns = "sanshi.zmops.cn"
    base_port = "127"
    base_hosts = ["{#VM.NAME}", "{#HM.NAME}", "{#VM.UUID}", "{#HV.UUID}"]
    base_ruleids = [10009, 10010, 10013, 10014]
    groupLinks_groupid = 46

    new_name = "修改SS测试主机原型"
    new_ip = "192.168.1.28"
    new_port = "721"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataHosts().delete_name(session=session, name=cls.base_name)

        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataHosts().delete_name(session=session, name=cls.new_name)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：hostprototype.create")
    def hostprototype_create(self, host=None, name=None, ruleid=None, templateids=None, groupLinks_groupid=None, groupPrototypes_name=None):
        api = HostPrototypeCreate(_host=self.host)
        api.host = host
        api.name = name
        api.ruleid = ruleid
        api.templateids = templateids
        api.groupLinks_groupid = groupLinks_groupid
        api.groupPrototypes_name = groupPrototypes_name
        api.get_response()
        return api.response

    @allure.step("调用接口：hostprototype.delete")
    def hostprototype_delete(self, hostids=None):
        api = HostPrototypeDelete(_host=self.host)
        api.hostids = hostids
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("创建测试数据")
    def case_create(self, host, group_prototypes_name, ruleid):
        response = self.hostprototype_create(host=host, name=self.base_name, ruleid=ruleid, groupLinks_groupid=[self.groupLinks_groupid],
                                             groupPrototypes_name=[group_prototypes_name])
        self.check_code(response=response, code=0)
        hostid = UtilsResponse().get_result(response=response)["hostids"][0]
        return hostid

    @allure.step("查询表：hosts")
    def select_hosts(self, hostid=None):
        session = self.db_session()
        sql = DataHosts().select_all_from_allKeys(session=session, hostid=hostid)
        return sql

    @allure.step("校验查询结果")
    def check_select(self, hostid):
        sql = self.select_hosts(hostid=hostid)
        assert sql == []

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("hostprototype.delete：删除的ID存在")
    @allure.story("删除主机原型：删除的ID存在")
    @allure.severity("blocker")
    def test_case_01(self):
        host = self.base_hosts[0]
        group_prototypes_name = self.base_hosts[0]
        ruleid = self.base_ruleids[0]
        hostid = self.case_create(host=host, group_prototypes_name=group_prototypes_name, ruleid=ruleid)

        response = self.hostprototype_delete(hostids=[hostid])
        self.check_code(response=response, code=0)
        self.check_select(hostid=hostid)

    @allure.title("hostprototype.delete：删除的ID不存在 500")
    @allure.story("删除主机原型：删除的ID不存在 500")
    def test_case_02(self):
        host = self.base_hosts[1]
        group_prototypes_name = self.base_hosts[1]
        ruleid = self.base_ruleids[1]
        hostid = self.case_create(host=host, group_prototypes_name=group_prototypes_name, ruleid=ruleid)

        response = self.hostprototype_delete(hostids=[hostid])
        self.check_code(response=response, code=0)
        self.check_select(hostid=hostid)

        response = self.hostprototype_delete(hostids=[hostid])
        self.check_code(response=response, code=100)

    @allure.title("hostprototype.delete：删除多个ID")
    @allure.story("删除主机原型：删除多个ID")
    def test_case_03(self):
        hostid_1 = self.case_create(host=self.base_hosts[2], group_prototypes_name=self.base_hosts[2], ruleid=self.base_ruleids[2])
        hostid_2 = self.case_create(host=self.base_hosts[3], group_prototypes_name=self.base_hosts[3], ruleid=self.base_ruleids[3])

        response = self.hostprototype_delete(hostids=[hostid_1, hostid_2])
        self.check_code(response=response, code=0)
        self.check_select(hostid=hostid_1)
        self.check_select(hostid=hostid_2)


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()

    # a = TestHostPrototypeDelete()
    # a.setup_class()
    # a.test_case_01()
    # a.test_case_02()
    # a.test_case_03()
    # a.test_case_06()
